@@ -231,21 +231,51 @@
 #ifndef MAP_STACK
 #define MAP_STACK 0
 #endif
+#ifndef MAP_FIXED_NOREPLACE
+#define MAP_FIXED_NOREPLACE 0
+#endif
+#ifndef MAP_SHARED_VALIDATE
+#define MAP_SHARED_VALIDATE 0
+#endif
+#ifndef MAP_SYNC
+#define MAP_SYNC 0
+#endif
+#ifndef MAP_UNINITIALIZED
+#define MAP_UNINITIALIZED 0
+#endif
 #ifndef MREMAP_MAYMOVE
 #define MREMAP_MAYMOVE 0
 #endif
 #ifndef MREMAP_FIXED
 #define MREMAP_FIXED 0
 #endif
-#ifndef F_DUPFD_CLOEXEC
-#define F_DUPFD_CLOEXEC 0
-#endif
 #ifndef MSG_CMSG_CLOEXEC
 #define MSG_CMSG_CLOEXEC 0
 #endif
 #ifndef SOCK_CLOEXEC
 #define SOCK_CLOEXEC 0
 #endif
+#ifndef F_DUPFD_CLOEXEC
+#define F_DUPFD_CLOEXEC 0
+#endif
+#ifndef F_ADD_SEALS
+#define F_ADD_SEALS 0
+#endif
+#ifndef F_GET_SEALS
+#define F_GET_SEALS 0
+#endif
+#ifndef F_SEAL_SEAL
+#define F_SEAL_SEAL 0
+#endif
+#ifndef F_SEAL_SHRINK
+#define F_SEAL_SHRINK 0
+#endif
+#ifndef F_SEAL_GROW
+#define F_SEAL_GROW 0
+#endif
+#ifndef F_SEAL_WRITE
+#define F_SEAL_WRITE 0
+#endif
 #ifndef F_OFD_GETLK
 #define F_OFD_GETLK 0
 #endif
@@ -570,3 +600,168 @@
 #ifndef STATX_ATTR_AUTOMOUNT
 #define STATX_ATTR_AUTOMOUNT 0
 #endif
+#ifndef AT_FDCWD
+#define AT_FDCWD 0
+#endif
+#ifndef AT_SYMLINK_NOFOLLOW
+#define AT_SYMLINK_NOFOLLOW 0
+#endif
+#ifndef AT_EACCESS
+#define AT_EACCESS 0
+#endif
+#ifndef AT_REMOVEDIR
+#define AT_REMOVEDIR 0
+#endif
+#ifndef AT_SYMLINK_FOLLOW
+#define AT_SYMLINK_FOLLOW 0
+#endif
+#ifndef AT_NO_AUTOMOUNT
+#define AT_NO_AUTOMOUNT 0
+#endif
+#ifndef AT_EMPTY_PATH
+#define AT_EMPTY_PATH 0
+#endif
+#ifndef AT_STATX_SYNC_TYPE
+#define AT_STATX_SYNC_TYPE 0
+#endif
+#ifndef AT_STATX_AS_STAT
+#define AT_STATX_AS_STAT 0
+#endif
+#ifndef AT_STATX_FORCE_SYNC
+#define AT_STATX_FORCE_SYNC 0
+#endif
+#ifndef AT_STATX_DONT_SYNC
+#define AT_STATX_DONT_SYNC 0
+#endif
+#ifndef AT_RECURSIVE
+#define AT_RECURSIVE 0
+#endif
+#ifndef OPEN_TREE_CLONE
+#define OPEN_TREE_CLONE 0
+#endif
+#ifndef FSOPEN_CLOEXEC
+#define FSOPEN_CLOEXEC 0
+#endif
+#ifndef FSPICK_CLOEXEC
+#define FSPICK_CLOEXEC 0
+#endif
+#ifndef FSPICK_SYMLINK_NOFOLLOW
+#define FSPICK_SYMLINK_NOFOLLOW 0
+#endif
+#ifndef FSPICK_NO_AUTOMOUNT
+#define FSPICK_NO_AUTOMOUNT 0
+#endif
+#ifndef FSPICK_EMPTY_PATH
+#define FSPICK_EMPTY_PATH 0
+#endif
+#ifndef MOVE_MOUNT_F_SYMLINKS
+#define MOVE_MOUNT_F_SYMLINKS 0
+#endif
+#ifndef MOVE_MOUNT_F_AUTOMOUNTS
+#define MOVE_MOUNT_F_AUTOMOUNTS 0
+#endif
+#ifndef MOVE_MOUNT_F_EMPTY_PATH
+#define MOVE_MOUNT_F_EMPTY_PATH 0
+#endif
+#ifndef MOVE_MOUNT_T_SYMLINKS
+#define MOVE_MOUNT_T_SYMLINKS 0
+#endif
+#ifndef MOVE_MOUNT_T_AUTOMOUNTS
+#define MOVE_MOUNT_T_AUTOMOUNTS 0
+#endif
+#ifndef MOVE_MOUNT_T_EMPTY_PATH
+#define MOVE_MOUNT_T_EMPTY_PATH 0
+#endif
+#ifndef P_PID
+#define P_PID 0
+#endif
+#ifndef P_PIDFD
+#define P_PIDFD 0
+#endif
+#ifndef P_PGID
+#define P_PGID 0
+#endif
+#ifndef P_ALL
+#define P_ALL 0
+#endif
+#ifndef FSCONFIG_SET_FLAG
+#define FSCONFIG_SET_FLAG 0
+#endif
+#ifndef FSCONFIG_SET_STRING
+#define FSCONFIG_SET_STRING 0
+#endif
+#ifndef FSCONFIG_SET_BINARY
+#define FSCONFIG_SET_BINARY 0
+#endif
+#ifndef FSCONFIG_SET_PATH
+#define FSCONFIG_SET_PATH 0
+#endif
+#ifndef FSCONFIG_SET_PATH_EMPTY
+#define FSCONFIG_SET_PATH_EMPTY 0
+#endif
+#ifndef FSCONFIG_SET_FD
+#define FSCONFIG_SET_FD 0
+#endif
+#ifndef FSCONFIG_CMD_CREATE
+#define FSCONFIG_CMD_CREATE 0
+#endif
+#ifndef FSCONFIG_CMD_RECONFIGURE
+#define FSCONFIG_CMD_RECONFIGURE 0
+#endif
+#ifndef MOUNT_ATTR_RDONLY
+#define MOUNT_ATTR_RDONLY 0
+#endif
+#ifndef MOUNT_ATTR_NOSUID
+#define MOUNT_ATTR_NOSUID 0
+#endif
+#ifndef MOUNT_ATTR_NODEV
+#define MOUNT_ATTR_NODEV 0
+#endif
+#ifndef MOUNT_ATTR_NOEXEC
+#define MOUNT_ATTR_NOEXEC 0
+#endif
+#ifndef MOUNT_ATTR__ATIME
+#define MOUNT_ATTR__ATIME 0
+#endif
+#ifndef MOUNT_ATTR_RELATIME
+#define MOUNT_ATTR_RELATIME 0
+#endif
+#ifndef MOUNT_ATTR_NOATIME
+#define MOUNT_ATTR_NOATIME 0
+#endif
+#ifndef MOUNT_ATTR_STRICTATIME
+#define MOUNT_ATTR_STRICTATIME 0
+#endif
+#ifndef MOUNT_ATTR_NODIRATIME
+#define MOUNT_ATTR_NODIRATIME 0
+#endif
+#if HAVE_SYSCALL
+# if __linux__ && !defined(SYS_pidfd_open)
+#  define SYS_pidfd_open 434
+# endif
+#else
+# undef SYS_pidfd_open
+#endif
+#ifndef SYS_pidfd_open
+# define SYS_pidfd_open -1
+#endif
+#if HAVE_SYSCALL
+# if __linux__ && !defined(SYS_pidfd_send_signal)
+#  define SYS_pidfd_send_signal 424
+# endif
+#else
+# undef SYS_pidfd_send_signal
+#endif
+#ifndef SYS_pidfd_send_signal
+# define SYS_pidfd_send_signal -1
+#endif
+#if HAVE_SYSCALL
+# if __linux__ && !defined(SYS_pidfd_getfd)
+#  define SYS_pidfd_getfd 438
+# endif
+#else
+# undef SYS_pidfd_getfd
+#endif
+#ifndef SYS_pidfd_getfd
+# define SYS_pidfd_getfd -1
+#endif
